##  Standardize Fact Sheet Colors and Order
It is recommended to align the colors following SAP LeanIX standards and also arrange Fact Sheets in the given order. This standardization helps all workspace users follow SAP LeanIX standard documentation and instructions effectively. To learn more about the standard fact sheet order and colors in the meta model v4 and how to change them, see [Fact Sheet Order and Colors](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of standard order and colors of fact sheets in the meta model v4 and learn how to change them.").
